<?php
// PHP Layers Menu 3.2.0-rc (C) 2001-2004 Marco Pratesi - http://www.marcopratesi.it/
// PHP Layers Menu 3.2.1-rc (C) 2012-2023 V.Krishn - http://www.insteps.net/

/**
* This file contains the code of the TreeMenu class.
* @package PHPLayersMenu
*/

/**
* This is the TreeMenu class of the PHP Layers Menu library.
*
* This class depends on the LayersMenuCommon class and on the PEAR conforming version of the PHPLib Template class, i.e. on HTML_Template_PHPLIB
*
* @version 3.2.1-rc
* @package PHPLayersMenu
*/
class TreeMenu5 extends TreeMenu
{


/**
* The constructor method; it initializates the menu system
* @return void
*/
function TreeMenu()
{
	$this->LayersMenuCommon();

	$this->treeMenuImagesType = 'png';
	$this->treeMenuTheme = '';
	$this->_treeMenu = array();

	$this->_nodesCount = 0;
	$this->_treeCount = 0;
	$this->_treeCountName = '';
	$this->tree = array();
	$this->_maxLevel = array();
	$this->_firstLevelCnt = array();
	$this->_firstItem = array();
	$this->_lastItem = array();
}


/**
* Method to prepare a new Tree Menu.
*
* This method processes items of a menu to prepare and return
* the corresponding Tree Menu code.
*
* @access public
* @param string $menu_name the name of the menu whose items have to be processed
* @return string
*/
function newTreeMenu(
	$menu_name = ''	// non consistent default...
	)
{
	if (!isset($this->_firstItem[$menu_name]) || !isset($this->_lastItem[$menu_name])) {
		$this->error("newTreeMenu: the first/last item of the menu '$menu_name' is not defined; please check if you have parsed its menu data.");
		return 0;
	}

	$this->treeType			= 5;
	$this->_treeCount		= $this->_treeCount + 1;
	$this->_treeMenu[$menu_name] = '';
	$alt_collapse			= '--';
	$alt_collapse_corner		= '--';
	$alt_collapse_corner_first	= '--';
	$alt_collapse_first		= '--';
	$alt_corner			= '`-';
	$alt_expand			= '+-';
	$alt_expand_corner		= '+-';
	$alt_expand_corner_first	= '+-';
	$alt_expand_first		= '+-';
	$alt_folder_closed		= '->';
	$alt_folder_open		= '->';
	$alt_leaf			= '->';
	$alt_space			= '  ';
	$alt_split			= '|-';
	$alt_split_first		= '|-';
	$alt_vertline			= '| ';

	$img_folder_closed		= $this->imgwww . $this->treeMenuTheme . 'tree_folder_closed.' . $this->treeMenuImagesType;
	$img_folder_open		= $this->imgwww . $this->treeMenuTheme . 'tree_folder_open.' . $this->treeMenuImagesType;
	$img_leaf			= $this->imgwww . $this->treeMenuTheme . 'tree_leaf.' . $this->treeMenuImagesType;

	for ($i=0; $i<=$this->_maxLevel[$menu_name]; $i++) {
		$levels[$i] = 0;
	}

	// Find last nodes of subtrees
	$last_level = $this->_maxLevel[$menu_name];
	for ($i=$this->_lastItem[$menu_name]; $i>=$this->_firstItem[$menu_name]; $i--) {
		if ($this->tree[$i]['level'] < $last_level) {
			for ($j=$this->tree[$i]['level']+1; $j<=$this->_maxLevel[$menu_name]; $j++) {
				$levels[$j] = 0;
			}
		}
		if ($levels[$this->tree[$i]['level']] == 0) {
			$levels[$this->tree[$i]['level']] = 1;
			$this->tree[$i]['last_item'] = 1;
		} else {
			$this->tree[$i]['last_item'] = 0;
		}
		$last_level = $this->tree[$i]['level'];
	}

	$toggle = '';
	$toggle_function_name = 'toggle' . $menu_name;
	$toggle_theme_name = 'treemenu_' . $this->treeMenuTheme . 'toggle';
	$this->_treeCountName = $this->_treeCount . $this->treeType . 'n';

	for ($cnt=$this->_firstItem[$menu_name]; $cnt<=$this->_lastItem[$menu_name]; $cnt++) {
		$cnt_ = $this->_treeCountName . ($cnt - $this->_firstItem[$menu_name] + 1);
		$cntnum_ = $cnt - $this->_firstItem[$menu_name] + 1;
		if ($this->tree[$cnt]['text'] == '---') {
			continue;	// separators are significant only for layers-based menus
		}
		if (isset($this->tree[$cnt]['selected']) && $this->tree[$cnt]['selected']) {
			$linkstyle = 'phplmselected';
		} else {
			$linkstyle = 'phplm';
		}

		$this->_treeMenu[$menu_name] .= '<li>';

		$not_a_leaf = $cnt<$this->_lastItem[$menu_name] && $this->tree[$cnt+1]['level']>$this->tree[$cnt]['level'];

		if ($this->tree[$cnt]['last_item'] == 1) {
		// corner at end of subtree or t-split
			if ($not_a_leaf) {
				if ($cnt == $this->_firstItem[$menu_name]) {
					$alt = $alt_collapse_corner_first; $alt_class = 'collapse_corner_first';
				} else {
					$alt = $alt_collapse_corner; $alt_class = 'collapse_corner';
				}
				$a_href_open_img2 = '<span class="' . $alt_class . '">' . $alt . '</span>';
			} else {
				$a_href_open_img2 = '<span class="corner">' . $alt_corner . '</span>';
			}
			$levels[$this->tree[$cnt]['level']-1] = 0;
		} else {
			if ($not_a_leaf) {
				if ($cnt == $this->_firstItem[$menu_name]) {
					$alt = $alt_collapse_first; $alt_class = 'collapse_first';
				} else {
					$alt = $alt_collapse; $alt_class = 'collapse';
				}
				$a_href_open_img2 = '<span class="' . $alt_class . '">' . $alt . '</span>';
			} else {
				if ($cnt == $this->_firstItem[$menu_name]) {
					$alt = $alt_split_first; $alt_class = 'split_first';
				} else {
					$alt = $alt_split; $alt_class = 'split';
				}
				$a_href_open_img2 = '<span class="' . $alt_class . '">' . $alt . '</span>';
			}
			$levels[$this->tree[$cnt]['level']-1] = 1;
		}

		if ($this->tree[$cnt]['parsed_href'] == '' || $this->tree[$cnt]['parsed_href'] == '#') {
			$a_href_open_img = '';
			$a_href_close_img = '';
			$a_href_open = '<a class="phplmnormal">';
			$a_href_close = '</a>';
		} else {
			$a_href_open_img = '';
			$a_href_close_img = '';
			$a_href_open = '<a href="' . $this->tree[$cnt]['parsed_href'] . '"' . $this->tree[$cnt]['parsed_title'] . $this->tree[$cnt]['parsed_target'] . ' class="' . $linkstyle . '">';
			$a_href_close = '</a>';
		}
		$a_href_open_img = $a_href_open_img2;

		if ($not_a_leaf) {
			$f = preg_split("/\\_(open|closed)\\.([\\w]{3})$/", basename($this->tree[$cnt]['parsed_icon']),-1,PREG_SPLIT_NO_EMPTY |PREG_SPLIT_DELIM_CAPTURE);
			$hash = '#'.@$f[0].':'.@$f[2];
			if ($this->tree[$cnt]['parsed_icon'] != '') {
				$this->_treeMenu[$menu_name] .= $a_href_open_img . '<img align="top" border="0" class="imgs folder" src="' . $this->tree[$cnt]['parsed_icon'] . $hash . '" alt="' . $alt_leaf . '" />' . $a_href_close_img;
			} else {
				$this->_treeMenu[$menu_name] .= $a_href_open_img . '<img align="top" border="0" class="imgs folder" src="' . $img_folder_open . '" alt="' . $alt_folder_open . '" />' . $a_href_close_img;
			}
		} else {
			if ($this->tree[$cnt]['parsed_icon'] != '') {
				$this->_treeMenu[$menu_name] .= $a_href_open_img . '<img align="top" border="0" src="' . $this->tree[$cnt]['parsed_icon'] . '" alt="' . $alt_leaf . '" />' . $a_href_close_img;
			} else {
				$this->_treeMenu[$menu_name] .= $a_href_open_img . '<img align="top" border="0" class="imgs" src="' . $img_leaf . '" alt="' . $alt_leaf . '" />' . $a_href_close_img;
			}
		}
		$this->_treeMenu[$menu_name] .= '&nbsp;' . $a_href_open . $this->tree[$cnt]['text'] . $a_href_close;

		if ($cnt<$this->_lastItem[$menu_name] && $this->tree[$cnt]['level']<$this->tree[$cnt+1]['level']) {
			$this->_treeMenu[$menu_name] .= "\n" . '<ul class="jt' . $cnt_ . 'son treemenu">';
			if ($this->tree[$cnt]['expanded'] != 1) {
				$toggle .= "'". $cntnum_ . "',";
			}
		} else { $this->_treeMenu[$menu_name] .= '</li>'; }

		if ($cnt>$this->_firstItem[$menu_name] && $this->tree[$cnt]['level']>$this->tree[$cnt+1]['level']) {
			for ($i=max(1, $this->tree[$cnt+1]['level']); $i<$this->tree[$cnt]['level']; $i++) {
				$this->_treeMenu[$menu_name] .= "</ul>\n</li>" . "\n";
			}
		} else { $this->_treeMenu[$menu_name] .= "\n"; }
	}

	$this->_treeMenu[$menu_name] =
	'<div class="phplmnormal ' . rtrim($this->treeMenuTheme,'_') . '"><ul id="jt' . $this->_treeCountName . '">' . "\n" .
	$this->_treeMenu[$menu_name] .
	'</ul></div>' . "\n";

	$t = new Template_PHPLIB();
	$t->setFile('tplfile', $this->libjsdir . 'layerstreemenu-init-toggle.ijs');

	$t->setVar(array(
		'theme_name'			=> $this->treeMenuTheme,
		'toggle_function_name'		=> $toggle_function_name,
		'toggle_theme_name'		=> $toggle_theme_name,
		'treemenu_toggle'		=> 'treemenu_toggle',
		'img_folder_closed'		=> $img_folder_closed,
		'img_folder_open'		=> $img_folder_open,
		'toggle_nums'			=> rtrim($toggle,','),
		'tree_count_name'		=> $this->_treeCountName,
		'theme_path'			=> dirname($img_folder_open)
	));

	static $_Count = array();
	@$_Count['count']++; @$_Count[$this->treeMenuTheme]++;

	$toggle_theme[$this->treeMenuTheme] = '';
	if($_Count[$this->treeMenuTheme] == 1) {
		$toggle_theme[$this->treeMenuTheme] = '_treemenu_toggle.data["'.$this->treeMenuTheme.'imgs"] = ["' .
 			dirname($img_folder_open) . '","'. basename($img_folder_closed) . '", "' . basename($img_folder_open) . '"];' . "\n";
        	$_Count[$this->treeMenuTheme]++;
	}

	$toggle_function = $t->parse('out', 'tplfile');
	$toggle_function =
	'<script type="text/javascript">' . "\n" .
	'<!--' . "\n" .
	$toggle_theme[$this->treeMenuTheme] .
	$toggle_function .
	'// -->' . "\n" .
	'</script>' . "\n";

	$this->_treeMenu[$menu_name] = "\n" . $this->_treeMenu[$menu_name] . $toggle_function;

	return $this->_treeMenu[$menu_name];
}


} /* END OF CLASS */

?>
